aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMatthew Somerville <matthew-github@dracos.co.uk>2018-03-20 14:32:13 +0000
committerMatthew Somerville <matthew-github@dracos.co.uk>2018-04-03 09:34:46 +0100
commit1ddef8a4fc90aa283ec2a24b1a5e332eea7e1069 (patch)
treef61a62a7dcddcad39b97944fc6113b917f492968
parent1a2f492b7d21555e9bf632d153bc0917ef39f33d (diff)
[FixaMinGata] Change pin colours.
-rw-r--r--perllib/FixMyStreet/Cobrand/FixaMinGata.pm7
1 files changed, 4 insertions, 3 deletions
diff --git a/perllib/FixMyStreet/Cobrand/FixaMinGata.pm b/perllib/FixMyStreet/Cobrand/FixaMinGata.pm
index 07a4ef920..59c64d455 100644
--- a/perllib/FixMyStreet/Cobrand/FixaMinGata.pm
+++ b/perllib/FixMyStreet/Cobrand/FixaMinGata.pm
@@ -108,12 +108,13 @@ sub filter_all_council_ids_list {
return @all_councils_ids; # Är detta rätt? //Rikard
}
# The pin is green is it's fixed, yellow if it's closed (but not fixed), and
# red otherwise.
sub pin_colour {
my ( $self, $p, $context ) = @_;
+ return 'green' if $p->is_closed;
return 'green' if $p->is_fixed;
- return 'yellow' if $p->is_closed;
+ return 'yellow' if $p->is_in_progress;
return 'red';
}
@@ -108,12 +108,13 @@ sub filter_all_council_ids_list {
return @all_councils_ids; # Är detta rätt? //Rikard
}
-# The pin is green is it's fixed, yellow if it's closed (but not fixed), and
-# red otherwise.
+# The pin is green is it's fixed or closed, yellow if it's in progress (not in a
+# confirmed state), and red otherwise.
sub pin_colour {
my ( $self, $p, $context ) = @_;